<h1 align="center">MAICA-幻象引擎</h1>
<div align="center">
<img src="https://maica.monika.love/assets/maica-text-finish-p.png" width=150>
</div>

***

<p align="center">中文 | <a href="/README_EN.md">English</a></p>

本页面是MAICA的指引页面, 当前位置是MAICA后端仓库.

MAICA项目的详细介绍页是https://maica.monika.love/.

要快速开始或了解授权, 请参阅https://maica.monika.love/tos.

MAICA的后端仓库地址是https://github.com/Mon1-innovation/MAICA.

MAICA的后端compact分支地址是https://github.com/Mon1-innovation/MAICA_Server_Submod

MAICA的子模组前端仓库地址是https://github.com/Mon1-innovation/MAICA_ChatSubmod.

MAICA LIA分支的模型地址是https://huggingface.co/edgeinfinity/MAICAv0-LIA-72B.

MAICA LOA分支的模型地址是https://huggingface.co/edgeinfinity/MAICAv0-LOA-7B.

MAICA-MTTS的仓库地址是https://github.com/Mon1-innovation/MAICA_MTTS.

MAICA-MTTS模型地址是https://huggingface.co/edgeinfinity/MTTSv0-VoiceClone.

MAICA的基本数据集仓库位于https://huggingface.co/datasets/edgeinfinity/MAICA_ds_basis.

MAICA的相关文档存储于https://github.com/Mon1-innovation/MAICA/tree/main/document.

请理解由于人力有限, 我们不在此对项目作额外介绍. 如需了解MAICA, 请前往上述详细介绍页面.
